# Generated by Django 2.2.16 on 2020-09-15 15:27

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('councilmatic_core', '0051_bill_last_action_date'),
    ]

    operations = [
        migrations.AlterField(
            model_name='bill',
            name='last_action_date',
            field=models.DateField(blank=True, null=True),
        ),
    ]
