# Generated by Django 2.2.9 on 2020-01-17 21:30

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('councilmatic_core', '0049_auto_20191114_1142'),
    ]

    operations = [
        migrations.DeleteModel(
            name='BillDocument',
        ),
    ]
