# Generated by Django 2.2.9 on 2020-01-30 19:03

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('councilmatic_core', '0050_remove_billdocument'),
    ]

    operations = [
        migrations.AddField(
            model_name='bill',
            name='last_action_date',
            field=models.DateTimeField(blank=True, null=True),
        ),
    ]
